package com.link.core.mybatis;

import com.alibaba.druid.pool.DruidDataSource;
import com.link.core.basic.database.DynamicDataSource;
import com.link.core.cllog.LCLogger;
import com.link.core.util.StringUtils;
import java.sql.SQLException;
import java.util.HashMap;
import java.util.Map;
import javax.annotation.Resource;
import org.apache.ibatis.session.SqlSessionFactory;
import org.mybatis.spring.SqlSessionFactoryBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;
import org.springframework.core.env.Environment;
import org.springframework.core.io.ResourceLoader;
import org.springframework.core.io.support.PathMatchingResourcePatternResolver;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.datasource.DataSourceTransactionManager;

@Configuration
public class MyBatisConfig {
   @Autowired
   private ResourceLoader resourceLoader;
   @Resource
   private Environment env;

   public DruidDataSource masterDataSource() {
      DruidDataSource druidDataSource = new DruidDataSource();
      druidDataSource.setDriverClassName(this.env.getProperty("spring.datasource.driverClassName"));
      druidDataSource.setUsername(this.env.getProperty("spring.datasource.username"));
      druidDataSource.setPassword(this.env.getProperty("spring.datasource.password"));
      druidDataSource.setMaxActive(Integer.valueOf(this.env.getProperty("spring.datasource.max-active")));
      druidDataSource.setInitialSize(Integer.valueOf(this.env.getProperty("spring.datasource.initial-size")));
      druidDataSource.setMinIdle(Integer.valueOf(this.env.getProperty("spring.datasource.min-idle")));
      String minEITM = this.env.getProperty("spring.datasource.minEvictableIdleTimeMillis");
      if (StringUtils.isNotBlank(minEITM)) {
         druidDataSource.setMinEvictableIdleTimeMillis((long)Integer.valueOf(minEITM));
      }

      String maxEITM = this.env.getProperty("spring.datasource.maxEvictableIdleTimeMillis");
      if (StringUtils.isNotBlank(maxEITM)) {
         druidDataSource.setMaxEvictableIdleTimeMillis((long)Integer.valueOf(maxEITM));
      }

      String tberm = this.env.getProperty("spring.datasource.timeBetweenEvictionRunsMillis");
      if (StringUtils.isNotBlank(tberm)) {
         druidDataSource.setMinEvictableIdleTimeMillis((long)Integer.valueOf(tberm));
      }

      String maxIdle = this.env.getProperty("spring.datasource.max-idle");
      if (StringUtils.isNotBlank(maxIdle)) {
         druidDataSource.setMaxIdle(Integer.valueOf(maxIdle));
      }

      druidDataSource.setTestOnBorrow(true);
      druidDataSource.setTestWhileIdle(true);
      druidDataSource.setValidationQuery("select 1 from dual");
      druidDataSource.setUrl(this.env.getProperty("spring.datasource.url"));

      try {
         druidDataSource.setFilters("stat");
      } catch (SQLException var7) {
         SQLException e = var7;
         LCLogger.error().withMessageKey("masterDataSource").withMessage(e.getMessage()).flush();
      }

      return druidDataSource;
   }

   public DruidDataSource slave01DataSource() {
      DruidDataSource druidDataSource = new DruidDataSource();
      druidDataSource.setDriverClassName(this.env.getProperty("spring.datasource.driverClassName"));
      druidDataSource.setUsername(this.env.getProperty("spring.datasource.username"));
      druidDataSource.setPassword(this.env.getProperty("spring.datasource.password"));
      druidDataSource.setMaxActive(Integer.valueOf(this.env.getProperty("spring.datasource.max-active")));
      druidDataSource.setInitialSize(Integer.valueOf(this.env.getProperty("spring.datasource.initial-size")));
      druidDataSource.setMinIdle(Integer.valueOf(this.env.getProperty("spring.datasource.min-idle")));
      String minEITM = this.env.getProperty("spring.datasource.minEvictableIdleTimeMillis");
      if (StringUtils.isNotBlank(minEITM)) {
         druidDataSource.setMinEvictableIdleTimeMillis((long)Integer.valueOf(minEITM));
      }

      String maxEITM = this.env.getProperty("spring.datasource.maxEvictableIdleTimeMillis");
      if (StringUtils.isNotBlank(maxEITM)) {
         druidDataSource.setMaxEvictableIdleTimeMillis((long)Integer.valueOf(maxEITM));
      }

      String tberm = this.env.getProperty("spring.datasource.timeBetweenEvictionRunsMillis");
      if (StringUtils.isNotBlank(tberm)) {
         druidDataSource.setMinEvictableIdleTimeMillis((long)Integer.valueOf(tberm));
      }

      String maxIdle = this.env.getProperty("spring.datasource.max-idle");
      if (StringUtils.isNotBlank(maxIdle)) {
         druidDataSource.setMaxIdle(Integer.valueOf(maxIdle));
      }

      druidDataSource.setTestOnBorrow(true);
      druidDataSource.setTestWhileIdle(true);
      druidDataSource.setValidationQuery("select 1 from dual");
      druidDataSource.setUrl(this.env.getProperty("spring.datasource.url1"));

      try {
         druidDataSource.setFilters("stat");
      } catch (SQLException var7) {
         SQLException e = var7;
         LCLogger.error().withMessageKey("slave01DataSource").withMessage(e.getMessage()).flush();
      }

      return druidDataSource;
   }

   public DruidDataSource slave02DataSource() {
      DruidDataSource druidDataSource = new DruidDataSource();
      druidDataSource.setDriverClassName(this.env.getProperty("spring.datasource.driverClassName"));
      druidDataSource.setUsername(this.env.getProperty("spring.datasource.username"));
      druidDataSource.setPassword(this.env.getProperty("spring.datasource.password"));
      druidDataSource.setMaxActive(Integer.valueOf(this.env.getProperty("spring.datasource.max-active")));
      druidDataSource.setInitialSize(Integer.valueOf(this.env.getProperty("spring.datasource.initial-size")));
      druidDataSource.setMinIdle(Integer.valueOf(this.env.getProperty("spring.datasource.min-idle")));
      String minEITM = this.env.getProperty("spring.datasource.minEvictableIdleTimeMillis");
      if (StringUtils.isNotBlank(minEITM)) {
         druidDataSource.setMinEvictableIdleTimeMillis((long)Integer.valueOf(minEITM));
      }

      String maxEITM = this.env.getProperty("spring.datasource.maxEvictableIdleTimeMillis");
      if (StringUtils.isNotBlank(maxEITM)) {
         druidDataSource.setMaxEvictableIdleTimeMillis((long)Integer.valueOf(maxEITM));
      }

      String tberm = this.env.getProperty("spring.datasource.timeBetweenEvictionRunsMillis");
      if (StringUtils.isNotBlank(tberm)) {
         druidDataSource.setMinEvictableIdleTimeMillis((long)Integer.valueOf(tberm));
      }

      String maxIdle = this.env.getProperty("spring.datasource.max-idle");
      if (StringUtils.isNotBlank(maxIdle)) {
         druidDataSource.setMaxIdle(Integer.valueOf(maxIdle));
      }

      druidDataSource.setTestOnBorrow(true);
      druidDataSource.setTestWhileIdle(true);
      druidDataSource.setValidationQuery("select 1 from dual");
      druidDataSource.setUrl(this.env.getProperty("spring.datasource.url2"));

      try {
         druidDataSource.setFilters("stat");
      } catch (SQLException var7) {
         SQLException e = var7;
         LCLogger.error().withMessageKey("slave02DataSource").withMessage(e.getMessage()).flush();
      }

      return druidDataSource;
   }

   public DruidDataSource lytDataSource() {
      DruidDataSource druidDataSource = new DruidDataSource();
      druidDataSource.setDriverClassName(this.env.getProperty("spring.datasource.driverClassName"));
      druidDataSource.setUsername(this.env.getProperty("spring.datasource.lyt-username"));
      druidDataSource.setPassword(this.env.getProperty("spring.datasource.lyt-password"));
      druidDataSource.setMaxActive(Integer.valueOf(this.env.getProperty("spring.datasource.max-active")));
      druidDataSource.setInitialSize(Integer.valueOf(this.env.getProperty("spring.datasource.initial-size")));
      druidDataSource.setMinIdle(Integer.valueOf(this.env.getProperty("spring.datasource.min-idle")));
      String minEITM = this.env.getProperty("spring.datasource.minEvictableIdleTimeMillis");
      if (StringUtils.isNotBlank(minEITM)) {
         druidDataSource.setMinEvictableIdleTimeMillis((long)Integer.valueOf(minEITM));
      }

      String maxEITM = this.env.getProperty("spring.datasource.maxEvictableIdleTimeMillis");
      if (StringUtils.isNotBlank(maxEITM)) {
         druidDataSource.setMaxEvictableIdleTimeMillis((long)Integer.valueOf(maxEITM));
      }

      String tberm = this.env.getProperty("spring.datasource.timeBetweenEvictionRunsMillis");
      if (StringUtils.isNotBlank(tberm)) {
         druidDataSource.setMinEvictableIdleTimeMillis((long)Integer.valueOf(tberm));
      }

      String maxIdle = this.env.getProperty("spring.datasource.max-idle");
      if (StringUtils.isNotBlank(maxIdle)) {
         druidDataSource.setMaxIdle(Integer.valueOf(maxIdle));
      }

      druidDataSource.setTestOnBorrow(true);
      druidDataSource.setTestWhileIdle(true);
      druidDataSource.setValidationQuery("select 1 from dual");
      druidDataSource.setUrl(this.env.getProperty("spring.datasource.lyturl"));

      try {
         druidDataSource.setFilters("stat");
      } catch (SQLException var7) {
         SQLException e = var7;
         LCLogger.error().withMessageKey("vipDataSource").withMessage(e.getMessage()).flush();
      }

      return druidDataSource;
   }

   public DruidDataSource lytSlaveDataSource() {
      DruidDataSource druidDataSource = new DruidDataSource();
      druidDataSource.setDriverClassName(this.env.getProperty("spring.datasource.driverClassName"));
      druidDataSource.setUsername(this.env.getProperty("spring.datasource.lyt-username"));
      druidDataSource.setPassword(this.env.getProperty("spring.datasource.lyt-password"));
      druidDataSource.setMaxActive(Integer.valueOf(this.env.getProperty("spring.datasource.max-active")));
      druidDataSource.setInitialSize(Integer.valueOf(this.env.getProperty("spring.datasource.initial-size")));
      druidDataSource.setMinIdle(Integer.valueOf(this.env.getProperty("spring.datasource.min-idle")));
      String minEITM = this.env.getProperty("spring.datasource.minEvictableIdleTimeMillis");
      if (StringUtils.isNotBlank(minEITM)) {
         druidDataSource.setMinEvictableIdleTimeMillis((long)Integer.valueOf(minEITM));
      }

      String maxEITM = this.env.getProperty("spring.datasource.maxEvictableIdleTimeMillis");
      if (StringUtils.isNotBlank(maxEITM)) {
         druidDataSource.setMaxEvictableIdleTimeMillis((long)Integer.valueOf(maxEITM));
      }

      String tberm = this.env.getProperty("spring.datasource.timeBetweenEvictionRunsMillis");
      if (StringUtils.isNotBlank(tberm)) {
         druidDataSource.setMinEvictableIdleTimeMillis((long)Integer.valueOf(tberm));
      }

      String maxIdle = this.env.getProperty("spring.datasource.max-idle");
      if (StringUtils.isNotBlank(maxIdle)) {
         druidDataSource.setMaxIdle(Integer.valueOf(maxIdle));
      }

      druidDataSource.setTestOnBorrow(true);
      druidDataSource.setTestWhileIdle(true);
      druidDataSource.setValidationQuery("select 1 from dual");
      druidDataSource.setUrl(this.env.getProperty("spring.datasource.lyturl1"));

      try {
         druidDataSource.setFilters("stat");
      } catch (SQLException var7) {
         SQLException e = var7;
         LCLogger.error().withMessageKey("lytSlaveDataSource").withMessage(e.getMessage()).flush();
      }

      return druidDataSource;
   }

   public DruidDataSource linkadmin() {
      DruidDataSource druidDataSource = new DruidDataSource();
      druidDataSource.setDriverClassName(this.env.getProperty("spring.datasource.driverClassName"));
      druidDataSource.setUsername(this.env.getProperty("spring.datasource.username"));
      druidDataSource.setPassword(this.env.getProperty("spring.datasource.password"));
      druidDataSource.setMaxActive(Integer.valueOf(this.env.getProperty("spring.datasource.max-active")));
      druidDataSource.setInitialSize(Integer.valueOf(this.env.getProperty("spring.datasource.initial-size")));
      druidDataSource.setMinIdle(Integer.valueOf(this.env.getProperty("spring.datasource.min-idle")));
      String minEITM = this.env.getProperty("spring.datasource.minEvictableIdleTimeMillis");
      if (StringUtils.isNotBlank(minEITM)) {
         druidDataSource.setMinEvictableIdleTimeMillis((long)Integer.valueOf(minEITM));
      }

      String maxEITM = this.env.getProperty("spring.datasource.maxEvictableIdleTimeMillis");
      if (StringUtils.isNotBlank(maxEITM)) {
         druidDataSource.setMaxEvictableIdleTimeMillis((long)Integer.valueOf(maxEITM));
      }

      String tberm = this.env.getProperty("spring.datasource.timeBetweenEvictionRunsMillis");
      if (StringUtils.isNotBlank(tberm)) {
         druidDataSource.setMinEvictableIdleTimeMillis((long)Integer.valueOf(tberm));
      }

      String maxIdle = this.env.getProperty("spring.datasource.max-idle");
      if (StringUtils.isNotBlank(maxIdle)) {
         druidDataSource.setMaxIdle(Integer.valueOf(maxIdle));
      }

      druidDataSource.setTestOnBorrow(true);
      druidDataSource.setTestWhileIdle(true);
      druidDataSource.setValidationQuery("select 1 from dual");
      druidDataSource.setUrl(this.env.getProperty("spring.datasource.linkadmin"));

      try {
         druidDataSource.setFilters("stat");
      } catch (SQLException var7) {
         SQLException e = var7;
         LCLogger.error().withMessageKey("linkadmin").withMessage(e.getMessage()).flush();
      }

      return druidDataSource;
   }

   public DruidDataSource qwDataSource() {
      DruidDataSource druidDataSource = new DruidDataSource();
      druidDataSource.setDriverClassName(this.env.getProperty("spring.datasource.driverClassName"));
      druidDataSource.setUsername(this.env.getProperty("spring.datasource.qwusername"));
      druidDataSource.setPassword(this.env.getProperty("spring.datasource.qwpassword"));
      druidDataSource.setMaxActive(Integer.valueOf(this.env.getProperty("spring.datasource.max-active")));
      druidDataSource.setInitialSize(Integer.valueOf(this.env.getProperty("spring.datasource.initial-size")));
      druidDataSource.setMinIdle(Integer.valueOf(this.env.getProperty("spring.datasource.min-idle")));
      String minEITM = this.env.getProperty("spring.datasource.minEvictableIdleTimeMillis");
      if (StringUtils.isNotBlank(minEITM)) {
         druidDataSource.setMinEvictableIdleTimeMillis((long)Integer.valueOf(minEITM));
      }

      String maxEITM = this.env.getProperty("spring.datasource.maxEvictableIdleTimeMillis");
      if (StringUtils.isNotBlank(maxEITM)) {
         druidDataSource.setMaxEvictableIdleTimeMillis((long)Integer.valueOf(maxEITM));
      }

      String tberm = this.env.getProperty("spring.datasource.timeBetweenEvictionRunsMillis");
      if (StringUtils.isNotBlank(tberm)) {
         druidDataSource.setMinEvictableIdleTimeMillis((long)Integer.valueOf(tberm));
      }

      String maxIdle = this.env.getProperty("spring.datasource.max-idle");
      if (StringUtils.isNotBlank(maxIdle)) {
         druidDataSource.setMaxIdle(Integer.valueOf(maxIdle));
      }

      druidDataSource.setTestOnBorrow(true);
      druidDataSource.setTestWhileIdle(true);
      druidDataSource.setValidationQuery("select 1 from dual");
      druidDataSource.setUrl(this.env.getProperty("spring.datasource.qwurl"));

      try {
         druidDataSource.setFilters("stat");
      } catch (SQLException var7) {
         SQLException e = var7;
         LCLogger.error().withMessageKey("qwDataSource").withMessage(e.getMessage()).flush();
      }

      return druidDataSource;
   }

   @Bean
   @Primary
   public DynamicDataSource dataSource() {
      Map<Object, Object> mapDatasource = new HashMap();
      mapDatasource.put("master", this.masterDataSource());
      mapDatasource.put("slave_01", this.slave01DataSource());
      mapDatasource.put("slave_02", this.slave02DataSource());
      mapDatasource.put("lyturl", this.lytDataSource());
      mapDatasource.put("linkadmin", this.linkadmin());
      mapDatasource.put("qwurl", this.qwDataSource());
      mapDatasource.put("lyt_slave", this.lytSlaveDataSource());
      DynamicDataSource dataSource = new DynamicDataSource();
      dataSource.setTargetDataSources(mapDatasource);
      dataSource.setDefaultTargetDataSource(this.masterDataSource());
      return dataSource;
   }

   @Bean
   @Primary
   public JdbcTemplate jdbcTemplate(DynamicDataSource dataSource) {
      JdbcTemplate jdbcTemplate = new JdbcTemplate();
      jdbcTemplate.setDataSource(dataSource);
      return jdbcTemplate;
   }

   @Bean
   @Primary
   public SqlSessionFactory sqlSessionFactory(DynamicDataSource ds) throws Exception {
      SqlSessionFactoryBean sfb = new SqlSessionFactoryBean();
      sfb.setDataSource(ds);
      sfb.setTypeAliasesPackage(this.env.getProperty("mybatis.typeAliasesPackage"));
      sfb.setMapperLocations((new PathMatchingResourcePatternResolver()).getResources(this.env.getProperty("mybatis.mapperLocations")));
      org.springframework.core.io.Resource resource = this.resourceLoader.getResource(this.env.getProperty("mybatis.config-location"));
      sfb.setConfigLocation(resource);
      return sfb.getObject();
   }

   @Bean
   @Primary
   public DataSourceTransactionManager dataSourceTransactionManager(DynamicDataSource dataSource) {
      DataSourceTransactionManager dataSourceTransactionManager = new DataSourceTransactionManager();
      dataSourceTransactionManager.setDataSource(dataSource);
      return dataSourceTransactionManager;
   }
}
